@@ -20,6 +20,8 @@ class Basic:
         self.voting_system = Settings.get_setting("voting_system", "False") == "True"
         self.new_music_only = Settings.get_setting("new_music_only", "False") == "True"
         self.logging_enabled = Settings.get_setting("logging_enabled", "True") == "True"
+        self.hashtags_active = Settings.get_setting("hashtags_active", "True") == "True"
+        self.embed_stream = Settings.get_setting("embed_stream", "False") == "True"
         self.online_suggestions = (
             Settings.get_setting("online_suggestions", "True") == "True"
         )
@@ -31,6 +33,7 @@ class Basic:
         self.downvotes_to_kick = int(Settings.get_setting("downvotes_to_kick", "2"))
         self.max_download_size = float(Settings.get_setting("max_download_size", "0"))
         self.max_playlist_items = int(Settings.get_setting("max_playlist_items", "10"))
+        self.max_queue_length = int(Settings.get_setting("max_queue_length", "0"))
         self.additional_keywords = Settings.get_setting("additional_keywords", "")
         self.forbidden_keywords = Settings.get_setting("forbidden_keywords", "")
         self._check_internet()
@@ -65,6 +68,20 @@ class Basic:
         Setting.objects.filter(key="logging_enabled").update(value=enabled)
         self.logging_enabled = enabled
 
+    @Settings.option
+    def set_hashtags_active(self, request: WSGIRequest) -> None:
+        """Enables or disables logging of requests and play logs based on the given value."""
+        enabled = request.POST.get("value") == "true"
+        Setting.objects.filter(key="hashtags_active").update(value=enabled)
+        self.hashtags_active = enabled
+
+    @Settings.option
+    def set_embed_stream(self, request: WSGIRequest) -> None:
+        """Enables or disables logging of requests and play logs based on the given value."""
+        enabled = request.POST.get("value") == "true"
+        Setting.objects.filter(key="embed_stream").update(value=enabled)
+        self.embed_stream = enabled
+
     @Settings.option
     def set_online_suggestions(self, request: WSGIRequest) -> None:
         """Enables or disables the voting system based on the given value."""
@@ -114,6 +131,13 @@ class Basic:
         Setting.objects.filter(key="max_playlist_items").update(value=value)
         self.max_playlist_items = value
 
+    @Settings.option
+    def set_max_queue_length(self, request: WSGIRequest) -> None:
+        """Sets the maximum number of songs that are downloaded from a playlist."""
+        value = int(request.POST.get("value"))  # type: ignore
+        Setting.objects.filter(key="max_queue_length").update(value=value)
+        self.max_queue_length = value
+
     @Settings.option
     def set_additional_keywords(self, request: WSGIRequest):
         """Sets the keywords to filter out of results."""
